% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/analyse_hydraulic.R
\name{analyse_hydraulic}
\alias{analyse_hydraulic}
\title{Perfom hydraulic analysis for a model}
\usage{
analyse_hydraulic(
  model,
  limnigraph,
  flood_duration,
  opening_scenario = c("combined", "close", "open"),
  dt_max = 0.5,
  Cd = 0.42,
  sim_id = NULL,
  stage = "",
  what = c("h", "eQ", "v"),
  verbose = getOption("floodam_building_verbose")
)
}
\arguments{
\item{model}{either a character, name given to the model or an object of
class model}

\item{limnigraph}{numeric, matrix of floodwater depth heights by instant t
for each exterior opening exposed to flooding}

\item{flood_duration}{numeric, duration of the flood event in seconds,
optional; if not provided, calculated using limnigraph}

\item{opening_scenario}{character, one of the following options: "open",
"closed", "combined". See details.}

\item{dt_max}{numeric, optional; maxmimum timestep for simulation}

\item{Cd}{numeric, optional; discharge coefficient for each opening,
default to getOption("floodam_building_hydraulic_discharge_coefficient")}

\item{sim_id}{character, optional; id of simulation if function called from a
loop}

\item{stage}{character, what are the stages that should be done, default to nothing}

\item{what}{character, outputs to be saved}

\item{verbose}{boolean, will floodam tells what it is doing, default to
getOption("floodam_building_verbose")}
}
\value{
list of matrix:
\itemize{
\item \code{h}: water depths in each rooms for each time step
\item \code{eQ}: water exchanges through openings for each time step
\item \code{v}: velocity of exchanges through openings for each time step
\item \code{eS}: wet surfaceof exchanges through openings for each time step
}
}
\description{
\code{analyse_hydraulic()} perfoms hydraulic analysis for a model.
}
\details{
\code{opening_scenario} controls the state of openings:
\itemize{
\item "open": scenario where all openings are open
\item "closed": scenario where all openings are closed
\item "combined": scenario where all exterior openings are closed and all interior
openings are open
}

If \code{flood_duration} is missing, it is computed from \code{limnigraph} (max time +
half an hour).
}
\examples{

# declaring input and output paths
model_path = list(
	data = system.file("extdata", package = "floodam.building"),
	output = tempdir()
)

# analyzing model 'adu_t' of type 'adu' using the sequential steps *load* 
# (load model data), *extract* (extract model data) and *hydraulic* 
model = analyse_model(
	model = "adu_t", 
	type = "adu", 
	stage = c("load", "extract", "hydraulic"), 
	path = model_path
)

#' # generate limnigraph
limnigraph = generate_limnigraph(
	time = c(0, 5400, 10800),
 	depth = cbind(external_1 = c(0, 3, 0), external_2 = c(0, 0, 0)),
		external = list(
			external_1 = c("door1", "window1", "window2"),
			external_2 = c("window3")
		)
)

hydraulic = analyse_hydraulic(
	model = model,
	limnigraph = limnigraph,
	sim_id = "test",
	stage = "hydraulic"
)

}
