% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/generate_limnigraph.R
\name{generate_limnigraph}
\alias{generate_limnigraph}
\title{Build a limnigraph}
\usage{
generate_limnigraph(
  time,
  depth,
  external,
  verbose = getOption("floodam_building_verbose")
)
}
\arguments{
\item{time}{numeric, time steps (in seconds) at which a specific floodwater depth is reached}

\item{depth}{numeric, depths (in meters) reached at time steps given by \code{time}}

\item{external}{character or list of characters, giving the names of the openings concerned by external limnigraphs}

\item{verbose}{boolean, will floodam tells what it is doing, default to getOption("floodam_building_verbose")}
}
\value{
list, with a matrix containing limnigraphs, and a list of the matching openings
}
\description{
\code{generate_limnigraph()} builds external limingraphs that are used as boundary
conditions for interior hydraulic simulation. It also gives the corresponding
openings to each limnigraph
}
\details{
\code{time} gives the different time steps used for all limnigraphs. Its length is used as the
standard.

\code{depth} can be a vector of the same length as \code{time}. In that case only one limnigraph will
be produced. For more limnigraphs a matrix with colnames shall be used.

\code{external} gives corresponding openings to each limnigraphs (columns of \code{depth}). In case
only one limingraph is given, external can be directly a character vector of corresponding
opnenings.
}
\examples{

# Simpliest limnigraph (one external)
limnigraph = generate_limnigraph(
	time = c(0, 1000, 2000),
	depth = c(0, 1, 0),
	external = "door"
)

# Limnigraph
limnigraph = generate_limnigraph(
	time = c(0, 1000, 2000),
	depth = cbind(ext_1 = c(0, 1, 0), ext_2 = 0),
	external = list(ext_1 = "door", ext_2 = "window")
)

}
